@@ -265,8 +265,8 @@ from django.utils import timezone
 from clixdev.projects._models import *
 
 # add your models here
+{_class}
 """
-# {_class}
 
 # preparing to remove due to beta
 def APP_URLS(app):
